@@ -131,6 +131,7 @@ virtualenv_create <- function(
     python <- virtualenv_starter(version)
 
 
+  local_prefix_python_lib_to_ld_library_path(python)
   check_can_be_virtualenv_starter(python, version)
 
   module <- module %||% virtualenv_module(python)
@@ -543,14 +544,24 @@ virtualenv_starter <- function(version = NULL, all = FALSE) {
     p <- p[utils::file_test("-f", p)]
     v <- numeric_version(vapply(p, function(python_path)
       tryCatch({
+        env <- character()
+        if (is_linux()) {
+          libpath <- file.path(dirname(dirname(python_path)), "lib")
+          if (file.exists(libpath)) {
+            ldpath <- paste(libpath, Sys.getenv("LD_LIBRARY_PATH"), sep = ":")
+            env <- paste("LD_LIBRARY_PATH=", ldpath, sep = "")
+          }
+        }
         v <- suppressWarnings(system2(
           python_path, "-EV",
-          stdout = TRUE, stderr = TRUE))
+          stdout = TRUE, stderr = TRUE,
+          env = env))
         # v should be something like "Python 3.10.6"
         if ((attr(v, "status") %||% 0) ||
             length(v) != 1L ||
             !startsWith(v, "Python "))
           return(NA_character_)
+        v <- sub("\\+.*$", "", v)
         substr(v, 8L, 999L)
       }, error = function(e) NA_character_), ""), strict = FALSE)
     df <- data.frame(version = v, path = p,
@@ -672,21 +683,26 @@ as_version_constraint_checkers <- function(version) {
   version <- unlist(strsplit(version, ",", fixed = TRUE))
 
   # given string like ">=3.8", match two groups, on ">=" and "3.8"
-  pattern <- "^([><=!]{0,2})\\s*([0-9.]*)"
+  pattern <- "^([><=!]{0,2})\\s*([0-9.a-zA-Z]*)"
 
   op <- sub(pattern, "\\1",  version)
   op[op == ""] <- "=="
 
-  ver <- sub(pattern, "\\2",  version)
-  ver <- numeric_version(ver)
+  ver_string <- sub(pattern, "\\2",  version)
+  ver <- numeric_version(ver_string, strict = FALSE)
 
-  .mapply(function(op, ver) {
-    op <- get(op, mode = "function")
+  .mapply(function(op, ver, ver_string) {
+    op <- as.symbol(op)
     force(ver)
+    force(ver_string)
 
     # return a "checker" function that takes a vector of versions and returns
     # a logical vector of if the version satisfies the constraint.
-    function(x) {
+    rlang::zap_srcref(eval(bquote(function(x) {
+      op <- .(op)
+      ver <- .(ver)
+      if (is.na(ver))
+        return(.(ver_string) %in% as.character(x))
       x <- numeric_version(x)
       # if the constraint version is missing minor or patch level, set
       # to 0, so we can match on all, equivalent to pip style syntax like '3.8.*'
@@ -696,8 +712,8 @@ as_version_constraint_checkers <- function(version) {
           x[, lvl] <- 0L
         }
       op(x, ver)
-    }
-  }, list(op, ver), NULL)
+    })))
+  }, list(op, ver, ver_string), NULL)
 }
 
 
